AppConfig class

Constructors

AppConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

generateLinkUrl → String
no setter
getDetailUrl → String
no setter
redirectUrl → String
no setter
no getter
setGetDetailUrl ← String
no getter
setRedirectUrl ← String
no getter
setSocketUrl ← String
no getter
setToken ← String
no getter
socketUrl → String
no setter
token → String
no setter