DevEnv class

Constructors

DevEnv()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

baseDomain ↔ String
getter/setter pair
baseRedirect ↔ String
getter/setter pair
generateLinkUlrl ↔ String
getter/setter pair
getDetailUrl ↔ String
getter/setter pair
redirectUrl ↔ String
getter/setter pair
socketUrl ↔ String
getter/setter pair
token ↔ String
getter/setter pair